/* finetd, an Internet Superserver
 *
 * Supports IPv4, IPv6 and UNIX domain sockets
 *
 ** Kris Katterjohn <katterjohn@gmail.com>
 ** http://finetd.sourceforge.net
 *
 * Copyright (c) 2008 Kris Katterjohn
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/* $Id: error.c 14 2008-02-24 07:13:53Z kjak $ */
/* https://finetd.svn.sourceforge.net/svnroot/finetd */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <errno.h>

static void quit(void)
{
	fprintf(stderr, "Quitting!\n");
	exit(1);
}

static void _e(char *fmt, va_list va)
{
	vfprintf(stderr, fmt, va);
	fprintf(stderr, "\n");
}

void error(char *fmt, ...)
{
	va_list va;

	va_start(va, fmt);
	_e(fmt, va);
	va_end(va);
}

void die(char *fmt, ...)
{
	va_list va;

	va_start(va, fmt);
	_e(fmt, va);
	va_end(va);

	quit();
}

/* Like perror(), but handles variable number of arguments */
static void _p(char *fmt, va_list va)
{
	vfprintf(stderr, fmt, va);
	fprintf(stderr, ": %s\n", strerror(errno));
}

void perr(char *fmt, ...)
{
	va_list va;

	va_start(va, fmt);
	_p(fmt, va);
	va_end(va);
}

void pdie(char *fmt, ...)
{
	va_list va;

	va_start(va, fmt);
	_p(fmt, va);
	va_end(va);

	quit();
}

