/* finetd, an Internet Superserver
 *
 * Supports IPv4, IPv6 and UNIX domain sockets
 *
 ** Kris Katterjohn <katterjohn@gmail.com>
 ** http://finetd.sourceforge.net
 *
 * Copyright (c) 2008 Kris Katterjohn
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/* $Id: finetd.h 16 2008-02-24 17:34:59Z kjak $ */
/* https://finetd.svn.sourceforge.net/svnroot/finetd */

#ifndef FINETDH
#define FINETDH

#include <sys/types.h>
#include <netinet/in.h>

/* POSIX.1g name - Uncomment if it's not defined */
#if 0
typedef unsigned int socklen_t;
#endif

/* RIP W. Richard Stevens */
#define SA struct sockaddr

/* Default listen() backlog */
#define LISTENQ 10

/* Default permissions for UNIX domain socket */
#define UDS_DEFAULT_MODE 0660

/* These are the built-in services */
#ifndef IPPORT_ECHO
#define IPPORT_ECHO	7
#endif
#ifndef IPPORT_DISCARD
#define IPPORT_DISCARD	9
#endif
#ifndef IPPORT_DAYTIME
#define IPPORT_DAYTIME	13
#endif
#ifndef IPPORT_CHARGEN
#define IPPORT_CHARGEN	19
#endif

/* Contains UNIX domain-specific information */
struct unixdom {
	uid_t uid; /* user id for UNIX socket owner */
	gid_t gid; /* group id for UNIX socket owner */
	mode_t mode; /* permissions for UNIX socket */
};

/* Holds information on a particular socket and associated service */
struct sserv {
	int fd; /* socket descriptor */

	char *name; /* service name */

	unsigned short port; /* port number */

	char *protostr; /* a string for the protocol WITHOUT version */
	int proto; /* protocol number */

	unsigned short family; /* protocol family (PF_INET, PF_INET6, PF_UNIX) */

	int type; /* socket type (SOCK_STREAM, SOCK_DGRAM, SOCK_SEQPACKET) */

	int wait; /* whether we wait for the process to exit or not */
	pid_t pid; /* pid being waited for, or 0 */
	int listenq; /* listen() backlog */

	uid_t uid; /* id for user-switching */
	gid_t gid; /* id for group-switching */

	char *path; /* path of the process to exec() */
	char **argv; /* args to pass to process */

	int internal; /* do we use path/argv or use a builtin_* function */

	struct unixdom un; /* UNIX domain socket ownership and permissions */

	int aborted; /* Count of how many times this service has abort()ed */

	int empty; /* Has this sserv had cleanup_sserv() run on it already? */
};

#endif

